package com.gic.haoban.manage.web.controller.chat;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.api.base.commons.BasePageInfo;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.PageHelperUtils;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.haoban.base.api.common.pojo.dto.WebLoginDTO;
import com.gic.haoban.common.utils.AuthWebRequestUtil;
import com.gic.haoban.manage.api.dto.chat.GroupChatDTO;
import com.gic.haoban.manage.api.dto.chat.GroupChatHmDTO;
import com.gic.haoban.manage.api.dto.hm.HmLinkChatDTO;
import com.gic.haoban.manage.api.dto.qdto.chat.ChatHmSearchQDTO;
import com.gic.haoban.manage.api.dto.qdto.chat.GroupChatSearchQDTO;
import com.gic.haoban.manage.api.dto.qdto.hm.HmLinkChatQDTO;
import com.gic.haoban.manage.api.service.chat.GroupChatApiService;
import com.gic.haoban.manage.api.service.chat.GroupChatHmApiService;
import com.gic.haoban.manage.web.vo.chat.HmLinkChatListVO;

/**
 * 
* @ClassName: GroupChatHmController
* @Description: 群活码
* @author xugh
* @date 2022年11月26日 上午9:32:56
*
 */
@RestController
@RequestMapping("/chat/hm")
public class GroupChatHmController {

    @Autowired
    private GroupChatHmApiService groupChatHmApiService;
    @Autowired
    private GroupChatApiService groupChatApiService;

    @RequestMapping("add")
    public RestResponse<Object> save(@RequestBody GroupChatHmDTO dto) {
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        dto.setCreatorId(loginUser.getClerkId());
        dto.setCreatorName(loginUser.getClerkName());
        dto.setModifierId(loginUser.getClerkId());
        dto.setModifierName(loginUser.getClerkName());
        dto.setWxEnterpriseId(loginUser.getWxEnterpriseId());
        dto.setEnterpriseId(loginUser.getEnterpriseId());
        this.groupChatHmApiService.save(dto);
        return RestResponse.successResult();
    }

    @RequestMapping("update")
    public RestResponse<Object> update(@RequestBody GroupChatHmDTO dto) {
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        dto.setWxEnterpriseId(loginUser.getWxEnterpriseId());
        dto.setEnterpriseId(loginUser.getEnterpriseId());
        dto.setModifierId(loginUser.getClerkId());
        dto.setModifierName(loginUser.getClerkName());
        this.groupChatHmApiService.save(dto);
        return RestResponse.successResult();
    }

    @RequestMapping("page")
    public RestResponse<Object> page(ChatHmSearchQDTO qdto, BasePageInfo basePageInfo) {
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        qdto.setWxEnterpriseId(loginUser.getWxEnterpriseId());
        qdto.setEnterpriseId(loginUser.getEnterpriseId());
        ServiceResponse<Page<GroupChatHmDTO>> page = this.groupChatHmApiService.listPage(qdto, basePageInfo);
        return RestResponse.successResult(page.getResult());
    }

    @RequestMapping("detail")
    public RestResponse<Object> detail(Long chatHmId) {
        if (null == chatHmId) {
            return RestResponse.failure("1", "群活码ID空");
        }
        ServiceResponse<GroupChatHmDTO> linkResp = this.groupChatHmApiService.detail(chatHmId);
        if (!linkResp.isSuccess()) {
            return RestResponse.failure("1", "群活码不存在");
        }
        GroupChatHmDTO hm = linkResp.getResult();
        return RestResponse.successResult(hm);
    }
    
    @RequestMapping("discard")
    public RestResponse<Object> discard(Long chatHmId) {
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        String wxEnterpriseId = loginUser.getWxEnterpriseId();
        String clerkId = loginUser.getClerkId();
        String clerkName = loginUser.getClerkName();
        this.groupChatHmApiService.discard(chatHmId, wxEnterpriseId, clerkId, clerkName);
        return RestResponse.successResult();
    }

    /**
     * 
    * @Title: linkRelation
    * @Description: 查询使用此活码的链接列表
    * @author xugh
    * @param chatHmId
    * @param basePageInfo
    * @return
    * @throws
     */
    @RequestMapping("link-relation")
    public RestResponse<Object> linkRelation(Long chatHmId, BasePageInfo basePageInfo) {
        if (null == chatHmId) {
            return RestResponse.failure("1", "群活码ID空");
        }
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        String wxEnterpriseId = loginUser.getWxEnterpriseId();
        HmLinkChatQDTO qdto = new HmLinkChatQDTO();
        qdto.setWxEnterpriseId(wxEnterpriseId);
        qdto.setEnterpriseId(loginUser.getEnterpriseId());
        qdto.setChatHmId(chatHmId);
        ServiceResponse<Page<HmLinkChatDTO>> pageResp = this.groupChatHmApiService.listPageChatLink(qdto, basePageInfo);
        Page<HmLinkChatDTO> page = pageResp.getResult();
        Page<HmLinkChatListVO> retPage = PageHelperUtils.changePageToCurrentPage(page, HmLinkChatListVO.class);
        return RestResponse.successResult(retPage);
    }

    /**
     * 
    * @Title: groupRelation
    * @Description: 查询群活码关联的群列表
    * @author xugh
    * @param chatHmId
    * @param basePageInfo
    * @return
    * @throws
     */
    @RequestMapping("group-relation")
    public RestResponse<Object> groupRelation(Long chatHmId, BasePageInfo basePageInfo) {
        if (null == chatHmId) {
            return RestResponse.failure("1", "群活码ID空");
        }
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        String wxEnterpriseId = loginUser.getWxEnterpriseId();
        GroupChatSearchQDTO qdto = new GroupChatSearchQDTO();
        qdto.setWxEnterpriseId(wxEnterpriseId);
        qdto.setEnterpriseId(loginUser.getEnterpriseId());
        qdto.setChatHmId(chatHmId);
        ServiceResponse<Page<GroupChatDTO>> page = this.groupChatApiService.listPage(qdto, basePageInfo);
        return RestResponse.successResult(page.getResult());
    }

}
